@@ -6,12 +6,13 @@ import sys
 
 import pytest
 
-from freeze_core._compat import IS_LINUX, IS_WINDOWS
+from freeze_core._compat import IS_LINUX, IS_UCRT
 from freeze_core.winmsvcr import MSVC_FILES, UCRT_FILES
 
 # This test is really necessary on Windows, but it runs in other environments,
 # so I let it be tested on Python 3.12 Linux, which is used on Ubuntu 24.04.
-# On other systems, it is disabled, including mingw.
+
+TEST_ENABLED = IS_UCRT or (IS_LINUX and sys.version_info[:2] == (3, 12))
 
 MSVC_EXPECTED = (
     # VC 2015 and 2017
@@ -37,10 +38,7 @@ UCRT_EXPECTED = (
 )
 
 
-@pytest.mark.skipif(
-    not (IS_WINDOWS or (IS_LINUX and sys.version_info[:2] == (3, 12))),
-    reason="Windows tests",
-)
+@pytest.mark.skipif(not TEST_ENABLED, reason="Windows tests")
 def test_files() -> None:
     """Test MSVC files."""
     assert MSVC_EXPECTED == MSVC_FILES
